# Copyright 2005 James Bunton <james@delx.cjb.net>
# Licensed for distribution under the GPL version 2, check COPYING for details

import utils
import config
from twisted.internet import reactor
if(utils.checkTwisted()):
	from twisted.xish.domish import Element
else:
	from tlib.domish import Element
import jabw
import config
import debug
import lang
import sha
import base64
import os
import os.path

SPOOL_UMASK = 0077

def makeAvatar(photo):
	""" Pass the photo element as an avatar, returns an Avatar object """
	avatarImageData = ""
	avatarImageType = ""
	for e in photo.elements():
		if(e.name == "BINVAL"):
			avatarImageData = base64.decodestring(e.__str__())
		if(e.name == "TYPE"):
			avatarImageType = e.__str__()
	
	if(avatarImageType != "image/png"):
		avatarImageData = utils.convertToPNG(avatarImageData)
	
	return Avatar(avatarImageData)



class Avatar:
	def __init__(self, imageData=""):
		self.imageData = imageData

	def getImageHash(self):
		return sha.sha(self.imageData).hexdigest()
	
	def makePhotoElement(self):
		photo = Element((None, "PHOTO"))
		type = photo.addElement("TYPE")
		type.addContent("image/png")
		binval = photo.addElement("BINVAL")
		binval.addContent(base64.encodestring(self.imageData))
		return photo

	def makeDataElement(self):
		data = Element((None, "data"))
		data["mimetype"] = "image/png"
		data.addContent(base64.encodestring(self.imageData))
		return data

	def __eq__(self, other):
		return (other and self.imageData == other.imageData)


class AvatarCache:
	def dir(self, key):
		d = utils.doPath(config.spooldir) + "/" + config.jid + "/avatars/" + key[0:3] + "/"
		if not os.path.exists(d):
			os.makedirs(d)
		return d
	
	def setAvatar(self, key, avatar):
		debug.log("AvatarCache: Setting avatar \"%s\"" % (key))
		prev_umask = os.umask(SPOOL_UMASK)
		f = open(self.dir(key) + key, 'w')
		f.write(avatar)
		f.close()
		os.umask(prev_umask)
	
	def getAvatar(self, key):
		filename = self.dir(key) + key
		if os.path.isfile(filename):
			debug.log("AvatarCache: Getting avatar \"%s\"" % (key))
			f = open(filename)
			data = f.read()
			f.close()
		else:
			debug.log("AvatarCache: Avatar not found \"%s\"" % (key))



